************* clearer syntax og importer datasett *********
clear all 
import excel "C:\Users\larsi\Documents\NTNUI Samba\Masteroppgave\Datasets\complete dataset.xlsx", sheet("Full sett") firstrow clear


***************INSTALLING PACKAGES*********************
ssc install xttest3
ssc install winsor2
ssc install extremes 

******** declaring time and fixed effect *******************
egen group_isin = group(isin)

gen nYear = real(year)
gen nQuarter =real(quarter)
gen qdate = yq(nYear, nQuarter)
format qdate %tq

xtset group_isin qdate, quarterly
****************************************************************

****************** TRIMMING USING 1% percintiles **************


su q, d
replace q = . if q > 117.3235  
replace q = . if q < .0536811 


su capExPPE, d
replace capExPPE = . if capExPPE > 1.593415   
replace capExPPE = . if capExPPE < 0 

su salesPPE, d
replace salesPPE = . if salesPPE > 58.84492  
replace salesPPE = . if salesPPE <  0

su NLAPPE, d
replace NLAPPE = . if NLAPPE > 108.8633 
replace NLAPPE = . if NLAPPE < -523.7235 


***************** CREATING VARIABLES ***********************
*** crafting industry specific q values ***
gen qInM = q if Industry == 1
gen qCnE = q if Industry == 2
gen qR = q if Industry == 3
gen qOnG = q if Industry == 4

gen lnqInM = log(qInM)
gen lnqCnE = log(qCnE)
gen lnqR = log(qR)
gen lnqOnG = log(qOnG)

*dummy for q under 1, bq= big q, sq = small q 
gen bq = 0
replace bq = 1 if q>1

gen sq=0
replace sq = 1 if q<1

gen BQ = q if q > 1

gen SQ = q if q < 1

*** dummy variable to differ from poositive and negative NLA ***
gen pNLA = NLA if NLA > 0
gen pNLAPPE = NLAPPE if NLA > 0

gen nNLA = NLA * -1 if NLA < 0
gen nNLAPPE = NLAPPE * -1 if NLA < 0


*** dummy variable to differ from small and large firms ***
*** small firms: those with total assets and PPE in the 1st quartile ***

su PPE, d
gen SMALLtot = totAssets if totAssets < 11985
gen LARGEtot = totAssets if totAssets > 431521.5

*** interaction variables between NLA and size ***

gen NLAsmall = NLAPPE*SMALLtot
gen NLAlarge = NLAPPE*LARGEtot
gen lNLAsmall = log(NLAsmall)
gen lNLAlarge = log(NLAlarge)

*** interaction between Tobin's q and NLA ***

gen NLAQ = q*NLAPPE
gen lnNLAQ = log(NLAQ)



********************************************************************

************** CREATING LAGGED VARIABLES *******************
*** lagging the credSpread by up to 5 quarters ***
gen L1credSpread = l.credSpread
gen L2credSpread = l2.credSpread
gen L3credSpread = l3.credSpread
gen L4credSpread = l4.credSpread
gen L5credSpread = l5.credSpread

*** creating yearly dummies for special quarters ***
gen quarter1 = 0
replace quarter1 = 1 if nQuarter == 1

gen quarter2 = 0
replace quarter2 = 1 if nQuarter == 2

gen quarter3 = 0 
replace quarter3 =1 if nQuarter == 3

gen quarter4 = 0
replace quarter4 = 1 if nQuarter == 4


*********************** CREATING DUMMIES FOR THE FINANCIAL CRISIS **********

*** for the financial crisis *** 
gen FinancialCrisis = 0
replace FinancialCrisis = 1 if nYear == 2008
replace FinancialCrisis = 1 if nYear == 2009

*** after the crisis (last quarter 2009)
gen postCrisis = 0
replace postCrisis = 1 if nYear > 2009



****************** logging all variables *********************
gen lncapExPPE = log(capExPPE)

gen lnsalesPPE = log(salesPPE)

gen lnq = log(q)

gen lncredSpread = log(credSpread)
gen lnL1credSpread = log(L1credSpread)
gen lnL2credSpread = log(L2credSpread)
gen lnL3credSpread = log(L3credSpread)
gen lnL4credSpread = log(L4credSpread)
gen lnL5credSpread = log(L5credSpread)

gen lnpNLA = log(pNLA)
gen lnpNLAPPE =log(pNLAPPE)

gen lnnNLA = log(nNLA)
gen lnnNLAPPE = log(nNLAPPE)

*****************************************
gen lnDepreciation = log(-depreciation)
gen lnTaxRate = log(taxRate)

************************* creating interaction terms ******************
gen postNLA = postCrisis * lnpNLAPPE
gen postPPE = postCrisis * PPE
gen postSales = postCrisis * lnsalesPPE
gen postCS = postCrisis * lncredSpread
gen postQ = postCrisis * lnq
gen postCSL1 = postCrisis * lnL1credSpread
gen postCSL2 = postCrisis * lnL2credSpread
gen postCSL3 = postCrisis * lnL3credSpread
gen postCSL4 = postCrisis * lnL4credSpread
gen postCSL5 = postCrisis * lnL5credSpread


**************** DESCPRITIVE STATISTICS ******************
*** summary statistics ***

sum capEx capExPPE q NLA NLAPPE sales salesPPE credSpread depreciation taxRate

sum q qInM qCnE qR qOnG

*** correlation matrix ***

corr capExPPE q NLAPPE salesPPE credSpread

corr capEx q NLA sales credSpread PPE


***************** REGRESSION 1 ****************************
reg capExPPE q 

test q

***************** REGRESSION 2 ****************************

reg capExPPE q NLAPPE salesPPE credSpread

test NLAPPE salesPPE credSpread


***************** REGRESSION 3 ****************************

xtreg capExPPE q, fe

test q

***************** REGRESSION 4 ****************************

xtreg capExPPE q NLAPPE salesPPE credSpread, fe

test NLAPPE salesPPE credSpread


***************** REGRESSION 5, fe with lags of credspread  ****************************

xtreg lncapExPPE lnq lnpNLAPPE lnsalesPPE lncredSpread lnL1credSpread lnL2credSpread lnL3credSpread lnL4credSpread lnL5credSpread, fe


***************** REGRESSION 6 ****************************

xtreg lncapExPPE lnq lnpNLAPPE lnsalesPPE lncredSpread lnL1credSpread, fe



***************** REGRESSION 7 ***********************
                *** we add seasonal dummies ***

xtreg lncapExPPE lnq lnpNLAPPE lnsalesPPE lncredSpread lnL1credSpread quarter2 quarter3 quarter4, fe

xttest3

xtserial lncapExPPE lnq lnpNLAPPE lnsalesPPE lncredSpread

*** need to use the cluster robust option in stata due to heteroskedasticity and serial corrrelation

********** REGRESSION 8 COMPLETE MODEL ***************
xtreg lncapExPPE lnq lnpNLAPPE lnsalesPPE lncredSpread lnL1credSpread quarter2 quarter3 quarter4, fe cluster()

estimates store fixed

********** REGRESSION 9 WITH RE INSTEAD OF FE ******************
xtreg lncapExPPE lnq lnpNLAPPE lnsalesPPE lncredSpread lnL1credSpread quarter2 quarter3 quarter4, re cluster()

estimates store random

hausman fixed random


*********************** TABLE 5 *************************************
**** REGRESSION 10 WITH NO RESTRICTIONS ON NLA *******
xtreg lncapExPPE lnq NLAPPE lnsalesPPE lncredSpread lnL1credSpread  quarter2 quarter3 quarter4, fe cluster()

*** REGRESSION 11 DIFFERENTIATING WITH NEGATIVE NLA***
xtreg lncapExPPE lnq lnnNLAPPE lnsalesPPE lncredSpread lnL1credSpread  quarter2 quarter3 quarter4, fe cluster()

*** REGRESSION 12 DIFFERENTIATING WITH FIRM SIZE ***

xtreg lncapExPPE lnq lNLAsmall lnsalesPPE lncredSpread lnL1credSpread quarter2 quarter3 quarter4, fe cluster()

xtreg lncapExPPE lnq lNLAlarge lnsalesPPE lncredSpread lnL1credSpread quarter2 quarter3 quarter4, fe cluster()

*** REGRESSION 13 WITH INTERACTION VARIABLE BETWEEN NLA AND Q, PECKING ORDER HYPOTHESIS

xtreg lncapExPPE lnNLAQ lnsalesPPE lncredSpread lnL1credSpread quarter2 quarter3 quarter4, fe cluster()



********** REGRESSION 14, DUMMY FOR FINANCIAL CRISIS ***************
xtreg lncapExPPE lnq lnpNLAPPE lnsalesPPE lncredSpread lnL1credSpread quarter2 quarter3 quarter4 FinancialCrisis, fe cluster()

***************** REGRESSION 11, twoway FE **********************************

xtreg lncapExPPE lnq lnpNLAPPE lnsalesPPE i.qdate, fe cluster(group_isin)

******************************************************************************


****************REGGRESSION 16 USER COST OF CAPITAL ******
xtreg lncapExPPE lnq lnpNLAPPE lnsalesPPE lnDepreciation lnTaxRate lncredSpread lnL1credSpread quarter2 quarter3 quarter4, fe cluster()
 
 
xtreg lncapExPPE lnq lnpNLAPPE lnsalesPPE lnDepreciation lncredSpread lnL1credSpread quarter2 quarter3 quarter4, fe cluster()


***************** TABLE 6 **********************************
****** REGRESSION 17, COMPLETE MODEL FOR INDUSTRIAL MACHINERY ********
xtreg lncapExPPE lnqInM lnpNLAPPE lnsalesPPE lncredSpread lnL1credSpread quarter2 quarter3 quarter4, fe cluster() 

* REGRESSION 18, COMPLETE MODEL FOR CONSTRUCTION AND ENGINEERING ***
xtreg lncapExPPE lnqCnE lnpNLAPPE lnsalesPPE lncredSpread lnL1credSpread quarter2 quarter3 quarter4, fe cluster()

**REGRESSION 19, COMPLETE MODEL FOR RENEWABLES ***				  
xtreg lncapExPPE lnqR lnpNLAPPE lnsalesPPE lncredSpread lnL1credSpread  quarter2 quarter3 quarter4, fe cluster()

** REGRESSION 20, COMPLETE MODEL FOR OIL AND GAS **					  
xtreg lncapExPPE lnqOnG lnpNLAPPE lnsalesPPE lncredSpread lnL1credSpread quarter2 quarter3 quarter4, fe cluster()

